import { Editor } from 'codemirror';
import type { EditorConfiguration } from 'codemirror';
import { FormatOptions } from 'sql-formatter';
import { default as React_2 } from 'react';

export declare type IEditor = Editor & {
    format(options: Partial<FormatOptions>): void;
};

declare type IFormatOptions = FormatOptions;

export declare const ReactCodemirror: React_2.ForwardRefExoticComponent<ReactCodemirrorProps & React_2.RefAttributes<Editor>>;

declare type ReactCodemirrorProps = {
    /**
     * @description codemirror的配置，
     * @link {https://codemirror.net/doc/manual.html#config}
     */
    options?: EditorConfiguration & {
        formatOptions?: IFormatOptions;
    };
    /**
     * @description editor发生后出发的事件，用来获取更改后，editor的内容
     */
    onChange?: (value: string) => void;
    /**
     * @description 对于智能提示，可以直接通过改字段提供，也可以通过`getExtraCompletions`字段使用一个函数来提供，
     *              函数方式是为了针对需要使用接口来获取的场景
     */
    extraCompletions?: string[];
    /**
     * @description 获取到当前的editor实例
     * @deprecated 使用ref来获取当前codemirror的实例
     */
    getInstance?: (cm: Editor) => Editor;
    /**
     * @description 使用函数来获取智能补全的待选项，可以返回一个Promise，该方法接受当前输入框中的值作为判断
     */
    getExtraCompletions?: (word?: string) => string[] | Promise<string[]>;
    /**
     * 在保存之后，触发格式化操作
     */
    formatAfterSave: boolean;
};

export { }
